@@ -22,10 +22,9 @@ constexpr int INV_WRITE{0x00020000}, INV_READ{0x00040000};
 } // namespace
 
 
-pqxx::internal::pq::PGconn *
-pqxx::blob::raw_conn(pqxx::connection *conn) noexcept
+pqxx::internal::pq::PGconn *pqxx::blob::raw_conn(pqxx::connection *cx) noexcept
 {
-  pqxx::internal::gate::connection_largeobject const gate{*conn};
+  pqxx::internal::gate::connection_largeobject const gate{*cx};
   return gate.raw_connection();
 }
 
@@ -37,21 +36,21 @@ pqxx::blob::raw_conn(pqxx::dbtransaction const &tx) noexcept
 }
 
 
-std::string pqxx::blob::errmsg(connection const *conn)
+std::string pqxx::blob::errmsg(connection const *cx)
 {
-  pqxx::internal::gate::const_connection_largeobject const gate{*conn};
+  pqxx::internal::gate::const_connection_largeobject const gate{*cx};
   return gate.error_message();
 }
 
 
 pqxx::blob pqxx::blob::open_internal(dbtransaction &tx, oid id, int mode)
 {
-  auto &conn{tx.conn()};
-  int const fd{lo_open(raw_conn(&conn), id, mode)};
+  auto &cx{tx.conn()};
+  int const fd{lo_open(raw_conn(&cx), id, mode)};
   if (fd == -1)
     throw pqxx::failure{internal::concat(
-      "Could not open binary large object ", id, ": ", errmsg(&conn))};
-  return {conn, fd};
+      "Could not open binary large object ", id, ": ", errmsg(&cx))};
+  return {cx, fd};
 }
 
 
@@ -118,8 +117,11 @@ pqxx::blob::~blob()
   catch (std::exception const &e)
   {
     if (m_conn != nullptr)
-      m_conn->process_notice(internal::concat(
-        "Failure while closing binary large object: ", e.what(), "\n"));
+    {
+      m_conn->process_notice("Failure while closing binary large object:\n");
+      // TODO: Make at least an attempt to append a newline.
+      m_conn->process_notice(e.what());
+    }
   }
 }
 
@@ -247,7 +249,7 @@ pqxx::oid pqxx::blob::from_buf(dbtransaction &tx, bytes_view data, oid id)
       {
         tx.conn().process_notice(internal::concat(
           "Could not clean up partially created large object ", id, ": ",
-          e.what()));
+          e.what(), "\n"));
       }
       catch (std::exception const &)
       {}
