@@ -2,7 +2,7 @@
  *
  * pqxx::errorhandler allows programs to receive errors and warnings.
  *
- * Copyright (c) 2000-2023, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2024, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this
@@ -19,7 +19,7 @@
 #include "pqxx/internal/header-post.hxx"
 
 
-pqxx::errorhandler::errorhandler(connection &conn) : m_home{&conn}
+pqxx::errorhandler::errorhandler(connection &cx) : m_home{&cx}
 {
   pqxx::internal::gate::connection_errorhandler{*m_home}.register_errorhandler(
     this);
