@@ -1,6 +1,6 @@
 /** Implementation of libpqxx exception classes.
  *
- * Copyright (c) 2000-2023, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2024, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this
@@ -15,7 +15,7 @@
 
 #include "pqxx/internal/header-post.hxx"
 
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
 pqxx::failure::failure(std::string const &whatarg, std::source_location loc) :
         std::runtime_error{whatarg}, location{loc}
 {}
@@ -33,74 +33,72 @@ pqxx::broken_connection::broken_connection() :
 
 pqxx::broken_connection::broken_connection(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        failure
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        failure{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::protocol_violation::protocol_violation(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        broken_connection
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        broken_connection{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::variable_set_to_null::variable_set_to_null(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        failure
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        failure{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::sql_error::sql_error(
-  std::string const &whatarg, std::string const &Q, char const sqlstate[]
-#if pqxx_have_source_location
+  std::string const &whatarg, std::string Q, char const *sqlstate
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        failure
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        failure{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
-, m_query{Q}, m_sqlstate{sqlstate ? sqlstate : ""} {}
+        },
+        m_query{std::move(Q)},
+        m_sqlstate{sqlstate ? sqlstate : ""}
+{}
 
 
 pqxx::sql_error::~sql_error() noexcept = default;
@@ -120,91 +118,86 @@ PQXX_PURE std::string const &pqxx::sql_error::sqlstate() const noexcept
 
 pqxx::in_doubt_error::in_doubt_error(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        failure
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        failure{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::transaction_rollback::transaction_rollback(
   std::string const &whatarg, std::string const &q, char const sqlstate[]
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        sql_error
-{
-  whatarg, q, sqlstate
-#if pqxx_have_source_location
-    ,
-    loc
+        sql_error{
+          whatarg, q, sqlstate
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::serialization_failure::serialization_failure(
   std::string const &whatarg, std::string const &q, char const sqlstate[]
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        transaction_rollback
-{
-  whatarg, q, sqlstate
-#if pqxx_have_source_location
-    ,
-    loc
+        transaction_rollback{
+          whatarg, q, sqlstate
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::statement_completion_unknown::statement_completion_unknown(
   std::string const &whatarg, std::string const &q, char const sqlstate[]
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        transaction_rollback
-{
-  whatarg, q, sqlstate
-#if pqxx_have_source_location
-    ,
-    loc
+        transaction_rollback{
+          whatarg, q, sqlstate
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::deadlock_detected::deadlock_detected(
   std::string const &whatarg, std::string const &q, char const sqlstate[]
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        transaction_rollback
-{
-  whatarg, q, sqlstate
-#if pqxx_have_source_location
-    ,
-    loc
+        transaction_rollback{
+          whatarg, q, sqlstate
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
@@ -215,13 +208,13 @@ pqxx::internal_error::internal_error(std::string const &whatarg) :
 
 pqxx::usage_error::usage_error(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
         std::logic_error{whatarg}
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
         ,
         location{loc}
 #endif
@@ -230,13 +223,13 @@ pqxx::usage_error::usage_error(
 
 pqxx::argument_error::argument_error(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
         invalid_argument{whatarg}
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
         ,
         location{loc}
 #endif
@@ -245,13 +238,13 @@ pqxx::argument_error::argument_error(
 
 pqxx::conversion_error::conversion_error(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
         domain_error{whatarg}
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
         ,
         location{loc}
 #endif
@@ -260,49 +253,47 @@ pqxx::conversion_error::conversion_error(
 
 pqxx::unexpected_null::unexpected_null(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        conversion_error
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        conversion_error{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::conversion_overrun::conversion_overrun(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
-        conversion_error
-{
-  whatarg
-#if pqxx_have_source_location
-    ,
-    loc
+        conversion_error{
+          whatarg
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
+          ,
+          loc
 #endif
-}
+        }
 {}
 
 
 pqxx::range_error::range_error(
   std::string const &whatarg
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
   ,
   std::source_location loc
 #endif
   ) :
         out_of_range{whatarg}
-#if pqxx_have_source_location
+#if defined(PQXX_HAVE_SOURCE_LOCATION)
         ,
         location{loc}
 #endif
