@@ -2,7 +2,7 @@
  *
  * pqxx::notification_receiver processes notifications.
  *
- * Copyright (c) 2000-2023, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2024, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this
@@ -21,10 +21,11 @@
 
 
 pqxx::notification_receiver::notification_receiver(
-  connection &c, std::string_view channel) :
-        m_conn{c}, m_channel{channel}
+  connection &cx, std::string_view channel) :
+        m_conn{cx}, m_channel{channel}
 {
-  pqxx::internal::gate::connection_notification_receiver{c}.add_receiver(this);
+  pqxx::internal::gate::connection_notification_receiver{cx}.add_receiver(
+    this);
 }
 
 
