@@ -2,7 +2,7 @@
  *
  * pqxx::result represents the set of result rows from a database query.
  *
- * Copyright (c) 2000-2023, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2024, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this
@@ -27,9 +27,8 @@ extern "C"
 #include "pqxx/internal/header-post.hxx"
 
 
-pqxx::row::row(
-  result const &r, result::size_type index, size_type cols) noexcept :
-        m_result{r}, m_index{index}, m_end{cols}
+pqxx::row::row(result r, result::size_type index, size_type cols) noexcept :
+        m_result{std::move(r)}, m_index{index}, m_end{cols}
 {}
 
 
@@ -208,17 +207,17 @@ bool PQXX_COLD pqxx::row::empty() const noexcept
 }
 
 
-pqxx::const_row_iterator pqxx::const_row_iterator::operator++(int) noexcept
+pqxx::const_row_iterator pqxx::const_row_iterator::operator++(int) & noexcept
 {
-  auto const old{*this};
+  auto old{*this};
   m_col++;
   return old;
 }
 
 
-pqxx::const_row_iterator pqxx::const_row_iterator::operator--(int) noexcept
+pqxx::const_row_iterator pqxx::const_row_iterator::operator--(int) & noexcept
 {
-  auto const old{*this};
+  auto old{*this};
   m_col--;
   return old;
 }
@@ -233,7 +232,7 @@ pqxx::const_reverse_row_iterator::base() const noexcept
 
 
 pqxx::const_reverse_row_iterator
-pqxx::const_reverse_row_iterator::operator++(int) noexcept
+pqxx::const_reverse_row_iterator::operator++(int) & noexcept
 {
   auto tmp{*this};
   operator++();
@@ -242,7 +241,7 @@ pqxx::const_reverse_row_iterator::operator++(int) noexcept
 
 
 pqxx::const_reverse_row_iterator
-pqxx::const_reverse_row_iterator::operator--(int)
+pqxx::const_reverse_row_iterator::operator--(int) &
 {
   auto tmp{*this};
   operator--();
