@@ -1,6 +1,6 @@
 /** Implementation of string conversions.
  *
- * Copyright (c) 2000-2023, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2024, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this
@@ -25,11 +25,14 @@
 #include "pqxx/internal/header-pre.hxx"
 
 #include "pqxx/except.hxx"
+#include "pqxx/internal/concat.hxx"
 #include "pqxx/strconv.hxx"
 
 #include "pqxx/internal/header-post.hxx"
 
 
+using namespace std::literals;
+
 namespace
 {
 #if !defined(PQXX_HAVE_CHARCONV_FLOAT)
@@ -37,8 +40,7 @@ namespace
 /** When building with libcxxrt on clang, you can't create thread_local objects
  * of non-POD types.  Any attempt will result in a link error.
  */
-constexpr bool have_thread_local
-{
+constexpr bool have_thread_local{
 #  if defined(PQXX_HAVE_THREAD_LOCAL)
   true
 #  else
@@ -48,13 +50,6 @@ constexpr bool have_thread_local
 #endif
 
 
-/// String comparison between string_view.
-constexpr inline bool equal(std::string_view lhs, std::string_view rhs)
-{
-  return lhs.compare(rhs) == 0;
-}
-
-
 /// The lowest possible value of integral type T.
 template<typename T> constexpr T bottom{std::numeric_limits<T>::min()};
 
@@ -68,11 +63,12 @@ template<typename T> constexpr T top{std::numeric_limits<T>::max()};
  */
 template<typename T> constexpr inline char *nonneg_to_buf(char *end, T value)
 {
+  constexpr int ten{10};
   char *pos = end;
   *--pos = '\0';
   do {
-    *--pos = pqxx::internal::number_to_digit(int(value % 10));
-    value = T(value / 10);
+    *--pos = pqxx::internal::number_to_digit(int(value % ten));
+    value = T(value / ten);
   } while (value > 0);
   return pos;
 }
@@ -167,16 +163,16 @@ zview integral_traits<T>::to_buf(char *begin, char *end, T const &value)
       "buffer too small.  " +
       pqxx::internal::state_buffer_overrun(space, need)};
 
-  char *pos;
-  if constexpr (std::is_unsigned_v<T>)
-    pos = nonneg_to_buf(end, value);
-  else if (value >= 0)
-    pos = nonneg_to_buf(end, value);
-  else if (value > bottom<T>)
-    pos = neg_to_buf(end, -value);
-  else
-    pos = bottom_to_buf<T>(end);
-
+  char *const pos{[end, &value]() {
+    if constexpr (std::is_unsigned_v<T>)
+      return nonneg_to_buf(end, value);
+    else if (value >= 0)
+      return nonneg_to_buf(end, value);
+    else if (value > bottom<T>)
+      return neg_to_buf(end, -value);
+    else
+      return bottom_to_buf<T>(end);
+  }()};
   return {pos, end - pos - 1};
 }
 
@@ -238,21 +234,26 @@ std::string demangle_type_name(char const raw[])
   // fall back to the raw name.
   //
   // When __cxa_demangle fails, it's guaranteed to return null.
-  char *demangled{abi::__cxa_demangle(raw, nullptr, nullptr, &status)};
+  std::unique_ptr<char, void (*)(char *)> const demangled{
+    abi::__cxa_demangle(raw, nullptr, nullptr, &status),
+    [](char *x) { std::free(x); }};
 #else
-  static constexpr char *demangled{nullptr};
+  std::unique_ptr<char> demangled{};
 #endif
-  std::string const name{(demangled == nullptr) ? raw : demangled};
-
-  // Check for nullness to work around jemalloc bug (see #508).
-  if (demangled != nullptr)
-    std::free(demangled);
-  return name;
+  return std::string{demangled ? demangled.get() : raw};
 }
 
+
+// TODO: Equivalents for converting a null in the other direction.
 void PQXX_COLD throw_null_conversion(std::string const &type)
 {
-  throw conversion_error{"Attempt to convert null to " + type + "."};
+  throw conversion_error{concat("Attempt to convert SQL null to ", type, ".")};
+}
+
+
+void PQXX_COLD throw_null_conversion(std::string_view type)
+{
+  throw conversion_error{concat("Attempt to convert SQL null to ", type, ".")};
 }
 
 
@@ -261,6 +262,7 @@ std::string PQXX_COLD state_buffer_overrun(int have_bytes, int need_bytes)
   // We convert these in standard library terms, not for the localisation
   // so much as to avoid "error cycles," if these values in turn should fail
   // to get enough buffer space.
+  // C++20: Use formatting library.
   std::stringstream have, need;
   have << have_bytes;
   need << need_bytes;
@@ -275,15 +277,13 @@ namespace
 template<typename TYPE>
 [[maybe_unused]] inline TYPE from_string_arithmetic(std::string_view in)
 {
-  char const *here;
+  char const *here{std::data(in)};
   auto const end{std::data(in) + std::size(in)};
 
   // Skip whitespace.  This is not the proper way to do it, but I see no way
   // that any of the supported encodings could ever produce a valid character
   // whose byte sequence would confuse this code.
-  for (here = std::data(in); here < end and (*here == ' ' or *here == '\t');
-       ++here)
-    ;
+  while (here < end and (*here == ' ' or *here == '\t')) ++here;
 
   TYPE out{};
   auto const res{std::from_chars(here, end, out)};
@@ -423,8 +423,7 @@ template<typename T>
   // work _for composite types._  I see no clean way to support leading
   // whitespace there without putting the code in here.  A shame about the
   // overhead, modest as it is, for the normal case.
-  for (; i < std::size(text) and (data[i] == ' ' or data[i] == '\t'); ++i)
-    ;
+  for (; i < std::size(text) and (data[i] == ' ' or data[i] == '\t'); ++i);
   if (i == std::size(text))
     throw pqxx::conversion_error{
       "Converting string to " + pqxx::type_name<T> +
@@ -481,8 +480,8 @@ namespace
 {
 constexpr bool valid_infinity_string(std::string_view text) noexcept
 {
-  return equal("infinity", text) or equal("Infinity", text) or
-         equal("INFINITY", text) or equal("inf", text);
+  return text == "inf" or text == "infinity" or text == "INFINITY" or
+         text == "Infinity";
 }
 
 
@@ -741,6 +740,7 @@ bool pqxx::string_traits<bool>::from_string(std::string_view text)
 {
   std::optional<bool> result;
 
+  // TODO: Don't really need to handle all these formats.
   switch (std::size(text))
   {
   case 0: result = false; break;
@@ -760,13 +760,13 @@ bool pqxx::string_traits<bool>::from_string(std::string_view text)
     }
     break;
 
-  case 4:
-    if (equal(text, "true") or equal(text, "TRUE"))
+  case std::size("true"sv):
+    if (text == "true" or text == "TRUE")
       result = true;
     break;
 
-  case 5:
-    if (equal(text, "false") or equal(text, "FALSE"))
+  case std::size("false"sv):
+    if (text == "false" or text == "FALSE")
       result = false;
     break;
 
