@@ -41,7 +41,7 @@ pqxx::stream_from::stream_from(
   transaction_base &tx, from_query_t, std::string_view query) :
         transaction_focus{tx, class_name}, m_char_finder{get_finder(tx)}
 {
-  tx.exec0(internal::concat("COPY ("sv, query, ") TO STDOUT"sv));
+  tx.exec(internal::concat("COPY ("sv, query, ") TO STDOUT"sv)).no_rows();
   register_me();
 }
 
@@ -50,7 +50,8 @@ pqxx::stream_from::stream_from(
   transaction_base &tx, from_table_t, std::string_view table) :
         transaction_focus{tx, class_name, table}, m_char_finder{get_finder(tx)}
 {
-  tx.exec0(internal::concat("COPY "sv, tx.quote_name(table), " TO STDOUT"sv));
+  tx.exec(internal::concat("COPY "sv, tx.quote_name(table), " TO STDOUT"sv))
+    .no_rows();
   register_me();
 }
 
@@ -62,9 +63,10 @@ pqxx::stream_from::stream_from(
 {
   if (std::empty(columns))
     PQXX_UNLIKELY
-  tx.exec0(internal::concat("COPY "sv, table, " TO STDOUT"sv));
-  else PQXX_LIKELY tx.exec0(
-    internal::concat("COPY "sv, table, "("sv, columns, ") TO STDOUT"sv));
+  tx.exec(internal::concat("COPY "sv, table, " TO STDOUT"sv)).no_rows();
+  else PQXX_LIKELY tx
+    .exec(internal::concat("COPY "sv, table, "("sv, columns, ") TO STDOUT"sv))
+    .no_rows();
   register_me();
 }
 
@@ -88,9 +90,9 @@ pqxx::stream_from pqxx::stream_from::table(
   transaction_base &tx, table_path path,
   std::initializer_list<std::string_view> columns)
 {
-  auto const &conn{tx.conn()};
+  auto const &cx{tx.conn()};
 #include "pqxx/internal/ignore-deprecated-pre.hxx"
-  return raw_table(tx, conn.quote_table(path), conn.quote_columns(columns));
+  return raw_table(tx, cx.quote_table(path), cx.quote_columns(columns));
 #include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
