@@ -45,14 +45,14 @@ std::shared_ptr<std::string> make_rollback_cmd()
 }
 } // namespace
 
-pqxx::transaction_base::transaction_base(connection &c) :
-        m_conn{c}, m_rollback_cmd{make_rollback_cmd()}
+pqxx::transaction_base::transaction_base(connection &cx) :
+        m_conn{cx}, m_rollback_cmd{make_rollback_cmd()}
 {}
 
 
 pqxx::transaction_base::transaction_base(
-  connection &c, std::string_view tname) :
-        m_conn{c}, m_name{tname}, m_rollback_cmd{make_rollback_cmd()}
+  connection &cx, std::string_view tname) :
+        m_conn{cx}, m_name{tname}, m_rollback_cmd{make_rollback_cmd()}
 {}
 
 
@@ -81,6 +81,7 @@ pqxx::transaction_base::~transaction_base()
     }
     catch (std::exception const &)
     {
+      // TODO: Make at least an attempt to append a newline.
       process_notice(e.what());
     }
   }
@@ -278,41 +279,13 @@ pqxx::result pqxx::transaction_base::exec_n(
 #include "pqxx/internal/ignore-deprecated-pre.hxx"
   result r{exec(query, desc)};
 #include "pqxx/internal/ignore-deprecated-post.hxx"
-  if (std::size(r) != rows)
-  {
-    std::string const N{
-      std::empty(desc) ? "" : internal::concat("'", desc, "'")};
-    throw unexpected_rows{internal::concat(
-      "Expected ", rows, " row(s) of data from query ", N, ", got ",
-      std::size(r), ".")};
-  }
+  r.expect_rows(rows);
   return r;
 }
 
 
-void pqxx::transaction_base::check_rowcount_prepared(
-  zview statement, result::size_type expected_rows,
-  result::size_type actual_rows)
-{
-  if (actual_rows != expected_rows)
-    throw unexpected_rows{internal::concat(
-      "Expected ", expected_rows, " row(s) of data from prepared statement '",
-      statement, "', got ", actual_rows, ".")};
-}
-
-
-void pqxx::transaction_base::check_rowcount_params(
-  std::size_t expected_rows, std::size_t actual_rows)
-{
-  if (actual_rows != expected_rows)
-    throw unexpected_rows{internal::concat(
-      "Expected ", expected_rows,
-      " row(s) of data from parameterised query, got ", actual_rows, ".")};
-}
-
-
 pqxx::result pqxx::transaction_base::internal_exec_prepared(
-  zview statement, internal::c_params const &args)
+  std::string_view statement, internal::c_params const &args)
 {
   command const cmd{*this, statement};
   return pqxx::internal::gate::connection_transaction{conn()}.exec_prepared(
@@ -321,7 +294,7 @@ pqxx::result pqxx::transaction_base::internal_exec_prepared(
 
 
 pqxx::result pqxx::transaction_base::internal_exec_params(
-  zview query, internal::c_params const &args)
+  std::string_view query, internal::c_params const &args)
 {
   command const cmd{*this, query};
   return pqxx::internal::gate::connection_transaction{conn()}.exec_params(
@@ -329,6 +302,16 @@ pqxx::result pqxx::transaction_base::internal_exec_params(
 }
 
 
+void pqxx::transaction_base::notify(
+  std::string_view channel, std::string_view payload)
+{
+  // For some reason, NOTIFY does not work as a parameterised statement,
+  // even just for the payload (which is supposed to be a normal string).
+  // Luckily, pg_notify() does.
+  exec("SELECT pg_notify($1, $2)", params{channel, payload}).one_row();
+}
+
+
 void pqxx::transaction_base::set_variable(
   std::string_view var, std::string_view value)
 {
@@ -356,6 +339,7 @@ void pqxx::transaction_base::close() noexcept
     }
     catch (std::exception const &e)
     {
+      // TODO: Make at least an attempt to append a newline.
       m_conn.process_notice(e.what());
     }
 
@@ -381,6 +365,7 @@ void pqxx::transaction_base::close() noexcept
     }
     catch (std::exception const &e)
     {
+      // TODO: Make at least an attempt to append a newline.
       m_conn.process_notice(e.what());
     }
   }
@@ -388,6 +373,7 @@ void pqxx::transaction_base::close() noexcept
   {
     try
     {
+      // TODO: Make at least an attempt to append a newline.
       m_conn.process_notice(e.what());
     }
     catch (std::exception const &)
@@ -434,7 +420,8 @@ void pqxx::transaction_base::unregister_focus(
   }
   catch (std::exception const &e)
   {
-    m_conn.process_notice(internal::concat(e.what(), "\n"));
+    // TODO: Make at least an attempt to append a newline.
+    m_conn.process_notice(e.what());
   }
 }
 
@@ -470,8 +457,9 @@ void pqxx::transaction_base::register_pending_error(zview err) noexcept
       {
         PQXX_UNLIKELY
         process_notice("UNABLE TO PROCESS ERROR\n");
+        // TODO: Make at least an attempt to append a newline.
         process_notice(e.what());
-        process_notice("ERROR WAS:");
+        process_notice("ERROR WAS:\n");
         process_notice(err);
       }
       catch (...)
@@ -495,8 +483,9 @@ void pqxx::transaction_base::register_pending_error(std::string &&err) noexcept
       {
         PQXX_UNLIKELY
         process_notice("UNABLE TO PROCESS ERROR\n");
+        // TODO: Make at least an attempt to append a newline.
         process_notice(e.what());
-        process_notice("ERROR WAS:");
+        process_notice("ERROR WAS:\n");
         process_notice(err);
       }
       catch (...)
