@@ -1,5 +1,9 @@
 #include <iostream>
 
+#include <pqxx/connection>
+#include <pqxx/nontransaction>
+#include <pqxx/transactor>
+
 #include "test_helpers.hxx"
 
 using namespace pqxx;
@@ -11,15 +15,13 @@ namespace
 {
 void test_017()
 {
-  connection conn;
-  perform(
-    [&conn]()
-    {
-      nontransaction tx{conn};
-      const auto r = tx.exec("SELECT * FROM generate_series(1, 4)");
-      PQXX_CHECK_EQUAL(r.size(), 4ul, "Weird query result.");
-      tx.commit();
-    });
+  connection cx;
+  perform([&cx] {
+    nontransaction tx{cx};
+    auto const r{tx.exec("SELECT * FROM generate_series(1, 4)")};
+    PQXX_CHECK_EQUAL(std::size(r), 4, "Weird query result.");
+    tx.commit();
+  });
 }
 
 
