@@ -18,10 +18,10 @@ constexpr int BoringYear{1977};
 
 // Count events and specifically events occurring in Boring Year, leaving the
 // former count in the result pair's first member, and the latter in second.
-std::pair<int, int> count_events(connection &conn, std::string const &table)
+std::pair<int, int> count_events(connection &cx, std::string const &table)
 {
   std::string const count_query{"SELECT count(*) FROM " + table};
-  nontransaction tx{conn};
+  nontransaction tx{cx};
   return std::make_pair(
     tx.query_value<int>(count_query),
     tx.query_value<int>(count_query + " WHERE year=" + to_string(BoringYear)));
@@ -34,29 +34,32 @@ struct deliberate_error : std::exception
 
 void test_037()
 {
-  connection conn;
+  connection cx;
   {
-    nontransaction tx{conn};
+    nontransaction tx{cx};
     test::create_pqxxevents(tx);
   }
 
   std::string const Table{"pqxxevents"};
 
   auto const Before{
-    perform([&conn, &Table] { return count_events(conn, Table); })};
+    perform([&cx, &Table] { return count_events(cx, Table); })};
   PQXX_CHECK_EQUAL(
     Before.second, 0,
     "Already have event for " + to_string(BoringYear) + ", cannot test.");
 
   {
-    quiet_errorhandler d(conn);
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
+    quiet_errorhandler d(cx);
+#include "pqxx/internal/ignore-deprecated-post.hxx"
     PQXX_CHECK_THROWS(
-      perform([&conn, &Table] {
-        robusttransaction<> tx{conn};
-        tx.exec0(
-          "INSERT INTO " + Table + " VALUES (" + to_string(BoringYear) +
-          ", "
-          "'yawn')");
+      perform([&cx, &Table] {
+        robusttransaction<> tx{cx};
+        tx.exec(
+            "INSERT INTO " + Table + " VALUES (" + to_string(BoringYear) +
+            ", "
+            "'yawn')")
+          .no_rows();
 
         throw deliberate_error();
       }),
@@ -64,8 +67,7 @@ void test_037()
       "Did not get expected exception from failing transactor.");
   }
 
-  auto const After{
-    perform([&conn, &Table] { return count_events(conn, Table); })};
+  auto const After{perform([&cx, &Table] { return count_events(cx, Table); })};
 
   PQXX_CHECK_EQUAL(After.first, Before.first, "Number of events changed.");
   PQXX_CHECK_EQUAL(
