@@ -35,19 +35,21 @@ void test_084()
     Query{"SELECT * FROM " + Table + " ORDER BY " + Key};
   constexpr int InitialSkip{2}, GetRows{3};
 
-  tx.exec0("DECLARE " + tx.quote_name(CurName) + " CURSOR FOR " + Query);
-  tx.exec0(
-    "MOVE " + pqxx::to_string(InitialSkip * GetRows) +
-    " "
-    "IN " +
-    tx.quote_name(CurName));
+  tx.exec("DECLARE " + tx.quote_name(CurName) + " CURSOR FOR " + Query)
+    .no_rows();
+  tx.exec(
+      "MOVE " + pqxx::to_string(InitialSkip * GetRows) +
+      " "
+      "IN " +
+      tx.quote_name(CurName))
+    .no_rows();
 
   // Wrap cursor in cursor stream.  Apply some trickery to get its name inside
   // a result field for this purpose.  This isn't easy because it's not
   // supposed to be easy; normally we'd only construct streams around existing
   // SQL cursors if they were being returned by functions.
   pqxx::icursorstream C{
-    tx, tx.exec("SELECT '" + tx.esc(CurName) + "'")[0][0], GetRows};
+    tx, tx.exec("SELECT $1", pqxx::params{CurName}).one_field(), GetRows};
 
   // Create parallel cursor to check results
   pqxx::icursorstream C2{tx, Query, "CHECKCUR", GetRows};
