@@ -8,13 +8,13 @@ namespace
 {
 void test_090()
 {
-  pqxx::connection conn;
+  pqxx::connection cx;
 
   // Test connection's adorn_name() function for uniqueness
   std::string const nametest{"basename"};
 
   PQXX_CHECK_NOT_EQUAL(
-    conn.adorn_name(nametest), conn.adorn_name(nametest),
+    cx.adorn_name(nametest), cx.adorn_name(nametest),
     "\"Unique\" names are not unique.");
 }
 } // namespace
