@@ -1,22 +1,23 @@
-#include "../test_helpers.hxx"
+#include <pqxx/pipeline>
+#include <pqxx/transaction>
 
-using namespace pqxx;
+#include "../test_helpers.hxx"
 
 namespace
 {
 void test_cancel_query()
 {
-  connection conn;
-  work tx{conn};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
   // Calling cancel_query() while none is in progress has no effect.
-  conn.cancel_query();
+  cx.cancel_query();
 
   // Nothing much is guaranteed about cancel_query, except that it doesn't make
   // the process die in flames.
-  pipeline p{tx, "test_cancel_query"};
+  pqxx::pipeline p{tx, "test_cancel_query"};
   p.retain(0);
   p.insert("SELECT pg_sleep(1)");
-  conn.cancel_query();
+  cx.cancel_query();
 }
 
 
