@@ -24,12 +24,12 @@ void test_error_verbosity()
     static_cast<int>(PQERRORS_VERBOSE),
     "error_verbosity enum should match PGVerbosity.");
 
-  pqxx::connection conn;
-  pqxx::work tx{conn};
-  conn.set_verbosity(pqxx::error_verbosity::terse);
-  tx.exec1("SELECT 1");
-  conn.set_verbosity(pqxx::error_verbosity::verbose);
-  tx.exec1("SELECT 2");
+  pqxx::connection cx;
+  pqxx::work tx{cx};
+  cx.set_verbosity(pqxx::error_verbosity::terse);
+  tx.exec("SELECT 1").one_row();
+  cx.set_verbosity(pqxx::error_verbosity::verbose);
+  tx.exec("SELECT 2").one_row();
 }
 
 
