@@ -10,11 +10,11 @@ using namespace std::literals;
 
 
 void compare_esc(
-  pqxx::connection &c, pqxx::transaction_base &t, char const text[])
+  pqxx::connection &cx, pqxx::transaction_base &t, char const text[])
 {
   std::size_t const len{std::size(std::string{text})};
   PQXX_CHECK_EQUAL(
-    c.esc(std::string_view{text, len}), t.esc(std::string_view{text, len}),
+    cx.esc(std::string_view{text, len}), t.esc(std::string_view{text, len}),
     "Connection & transaction escape differently.");
 
   PQXX_CHECK_EQUAL(
@@ -37,7 +37,7 @@ void compare_esc(
 }
 
 
-void test_esc(pqxx::connection &c, pqxx::transaction_base &t)
+void test_esc(pqxx::connection &cx, pqxx::transaction_base &t)
 {
   PQXX_CHECK_EQUAL(
     t.esc(std::string_view{"", 0}), "",
@@ -49,11 +49,11 @@ void test_esc(pqxx::connection &c, pqxx::transaction_base &t)
     t.esc(std::string_view{"hello"}), "hello", "Trivial escape went wrong.");
   char const *const escstrings[]{"x", " ", "", nullptr};
   for (std::size_t i{0}; escstrings[i] != nullptr; ++i)
-    compare_esc(c, t, escstrings[i]);
+    compare_esc(cx, t, escstrings[i]);
 }
 
 
-void test_quote(pqxx::connection &c, pqxx::transaction_base &t)
+void test_quote(pqxx::connection &cx, pqxx::transaction_base &t)
 {
   PQXX_CHECK_EQUAL(t.quote("x"), "'x'", "Basic quote() fails.");
   PQXX_CHECK_EQUAL(
@@ -65,7 +65,7 @@ void test_quote(pqxx::connection &c, pqxx::transaction_base &t)
     t.quote(std::string{"'"}), "''''", "Escaping quotes goes wrong.");
 
   PQXX_CHECK_EQUAL(
-    t.quote("x"), c.quote("x"),
+    t.quote("x"), cx.quote("x"),
     "Connection and transaction quote differently.");
 
   char const *test_strings[]{"",   "x",   "\\", "\\\\", "'",
@@ -94,10 +94,10 @@ void test_quote_name(pqxx::transaction_base &t)
 void test_esc_raw_unesc_raw(pqxx::transaction_base &t)
 {
   constexpr char binary[]{"1\0023\\4x5"};
-  std::basic_string<std::byte> const data(
+  pqxx::bytes const data(
     reinterpret_cast<std::byte const *>(binary), std::size(binary));
-  std::string const escaped{t.esc_raw(
-    std::basic_string_view<std::byte>{std::data(data), std::size(binary)})};
+  std::string const escaped{
+    t.esc_raw(pqxx::bytes_view{std::data(data), std::size(binary)})};
 
   for (auto const i : escaped)
   {
@@ -145,10 +145,10 @@ void test_esc_like(pqxx::transaction_base &tx)
 
 void test_escaping()
 {
-  pqxx::connection conn;
-  pqxx::work tx{conn};
-  test_esc(conn, tx);
-  test_quote(conn, tx);
+  pqxx::connection cx;
+  pqxx::work tx{cx};
+  test_esc(cx, tx);
+  test_quote(cx, tx);
   test_quote_name(tx);
   test_esc_raw_unesc_raw(tx);
   test_esc_like(tx);
@@ -158,8 +158,8 @@ void test_escaping()
 void test_esc_escapes_into_buffer()
 {
 #if defined(PQXX_HAVE_CONCEPTS)
-  pqxx::connection conn;
-  pqxx::work tx{conn};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
   std::string buffer;
   buffer.resize(20);
@@ -168,7 +168,7 @@ void test_esc_escapes_into_buffer()
   auto escaped_text{tx.esc(text, buffer)};
   PQXX_CHECK_EQUAL(escaped_text, "Ain''t", "Escaping into buffer went wrong.");
 
-  std::basic_string<std::byte> const data{std::byte{0x22}, std::byte{0x43}};
+  pqxx::bytes const data{std::byte{0x22}, std::byte{0x43}};
   auto escaped_data(tx.esc(data, buffer));
   PQXX_CHECK_EQUAL(escaped_data, "\\x2243", "Binary data escaped wrong.");
 #endif
@@ -178,8 +178,8 @@ void test_esc_escapes_into_buffer()
 void test_esc_accepts_various_types()
 {
 #if defined(PQXX_HAVE_CONCEPTS) && defined(PQXX_HAVE_SPAN)
-  pqxx::connection conn;
-  pqxx::work tx{conn};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
   std::string buffer;
   buffer.resize(20);
@@ -198,12 +198,11 @@ void test_esc_accepts_various_types()
 void test_binary_esc_checks_buffer_length()
 {
 #if defined(PQXX_HAVE_CONCEPTS) && defined(PQXX_HAVE_SPAN)
-  pqxx::connection conn;
-  pqxx::work tx{conn};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
   std::string buf;
-  std::basic_string<std::byte> bin{
-    std::byte{'b'}, std::byte{'o'}, std::byte{'o'}};
+  pqxx::bytes bin{std::byte{'b'}, std::byte{'o'}, std::byte{'o'}};
 
   buf.resize(2 * std::size(bin) + 3);
   pqxx::ignore_unused(tx.esc(bin, buf));
