@@ -6,11 +6,10 @@ namespace
 {
 void test_read_transaction()
 {
-  pqxx::connection conn;
-  pqxx::read_transaction tx{conn};
+  pqxx::connection cx;
+  pqxx::read_transaction tx{cx};
   PQXX_CHECK_EQUAL(
-    tx.exec("SELECT 1")[0][0].as<int>(), 1,
-    "Bad result from read transaction.");
+    tx.query_value<int>("SELECT 1"), 1, "Bad result from read transaction.");
 
   PQXX_CHECK_THROWS(
     tx.exec("CREATE TABLE should_not_exist(x integer)"), pqxx::sql_error,
