@@ -5,57 +5,63 @@
 
 namespace
 {
-void test_exec0(pqxx::transaction_base &trans)
+void test_exec0(pqxx::transaction_base &tx)
 {
-  pqxx::result E{trans.exec0("SELECT * FROM pg_tables WHERE 0 = 1")};
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
+  pqxx::result E{tx.exec0("SELECT * FROM pg_tables WHERE 0 = 1")};
   PQXX_CHECK(std::empty(E), "Nonempty result from exec0.");
 
   PQXX_CHECK_THROWS(
-    trans.exec0("SELECT 99"), pqxx::unexpected_rows,
+    tx.exec0("SELECT 99"), pqxx::unexpected_rows,
     "Nonempty exec0 result did not throw unexpected_rows.");
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
-void test_exec1(pqxx::transaction_base &trans)
+void test_exec1(pqxx::transaction_base &tx)
 {
-  pqxx::row R{trans.exec1("SELECT 99")};
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
+  pqxx::row R{tx.exec1("SELECT 99")};
   PQXX_CHECK_EQUAL(std::size(R), 1, "Wrong size result from exec1.");
   PQXX_CHECK_EQUAL(R.front().as<int>(), 99, "Wrong result from exec1.");
 
   PQXX_CHECK_THROWS(
-    trans.exec1("SELECT * FROM pg_tables WHERE 0 = 1"), pqxx::unexpected_rows,
+    tx.exec1("SELECT * FROM pg_tables WHERE 0 = 1"), pqxx::unexpected_rows,
     "Empty exec1 result did not throw unexpected_rows.");
   PQXX_CHECK_THROWS(
-    trans.exec1("SELECT * FROM generate_series(1, 2)"), pqxx::unexpected_rows,
+    tx.exec1("SELECT * FROM generate_series(1, 2)"), pqxx::unexpected_rows,
     "Two-row exec1 result did not throw unexpected_rows.");
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
-void test_exec_n(pqxx::transaction_base &trans)
+void test_exec_n(pqxx::transaction_base &tx)
 {
-  pqxx::result R{trans.exec_n(3u, "SELECT * FROM generate_series(1, 3)")};
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
+  pqxx::result R{tx.exec_n(3u, "SELECT * FROM generate_series(1, 3)")};
   PQXX_CHECK_EQUAL(std::size(R), 3, "Wrong result size from exec_n.");
 
   PQXX_CHECK_THROWS(
-    trans.exec_n(2u, "SELECT * FROM generate_series(1, 3)"),
+    tx.exec_n(2u, "SELECT * FROM generate_series(1, 3)"),
     pqxx::unexpected_rows,
     "exec_n did not throw unexpected_rows for an undersized result.");
   PQXX_CHECK_THROWS(
-    trans.exec_n(4u, "SELECT * FROM generate_series(1, 3)"),
+    tx.exec_n(4u, "SELECT * FROM generate_series(1, 3)"),
     pqxx::unexpected_rows,
     "exec_n did not throw unexpected_rows for an oversized result.");
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
-void test_query_value(pqxx::connection &conn)
+void test_query_value(pqxx::connection &cx)
 {
-  pqxx::work tx{conn};
+  pqxx::work tx{cx};
 
   PQXX_CHECK_EQUAL(
     tx.query_value<int>("SELECT 84 / 2"), 42,
     "Got wrong value from query_value.");
   PQXX_CHECK_THROWS(
-    tx.query_value<int>("SAVEPOINT dummy"), pqxx::unexpected_rows,
+    tx.query_value<int>("SAVEPOINT dummy"), pqxx::usage_error,
     "Got field when none expected.");
   PQXX_CHECK_THROWS(
     tx.query_value<int>("SELECT generate_series(1, 2)"), pqxx::unexpected_rows,
@@ -76,21 +82,21 @@ void test_query_value(pqxx::connection &conn)
 
 void test_transaction_base()
 {
-  pqxx::connection conn;
+  pqxx::connection cx;
   {
-    pqxx::work tx{conn};
+    pqxx::work tx{cx};
     test_exec_n(tx);
     test_exec0(tx);
     test_exec1(tx);
   }
-  test_query_value(conn);
+  test_query_value(cx);
 }
 
 
 void test_transaction_query()
 {
-  pqxx::connection c;
-  pqxx::work tx{c};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
   std::vector<std::string> names;
   std::vector<int> salaries;
@@ -113,8 +119,8 @@ void test_transaction_query()
 
 void test_transaction_query_params()
 {
-  pqxx::connection c;
-  pqxx::work tx{c};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
   int outcome{-1};
 
@@ -127,6 +133,7 @@ void test_transaction_query_params()
     outcome, 64, "Parameterised query() produced wrong result.");
 
   outcome = -1;
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
   for (auto [value] :
        tx.query_n<int>(1, "SELECT * FROM generate_series(1, $1)", {1}))
   {
@@ -172,6 +179,7 @@ void test_transaction_query_params()
     opt3_a, 12, "Multi-column query01() with params gave wrong result.");
   PQXX_CHECK_EQUAL(
     opt3_b, 99, "Multi-column query01() with params gave wrong result.");
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
@@ -181,8 +189,8 @@ void test_transaction_for_query()
     "SELECT i, concat('x', (2*i)::text) "
     "FROM generate_series(1, 3) AS i "
     "ORDER BY i"};
-  pqxx::connection conn;
-  pqxx::work tx{conn};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
   std::string ints;
   std::string strings;
   tx.for_query(query, [&ints, &strings](int i, std::string const &s) {
@@ -214,8 +222,8 @@ void test_transaction_for_stream()
     "SELECT i, concat('x', (2*i)::text) "
     "FROM generate_series(1, 3) AS i "
     "ORDER BY i"};
-  pqxx::connection conn;
-  pqxx::work tx{conn};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
   std::string ints;
   std::string strings;
   tx.for_stream(query, [&ints, &strings](int i, std::string const &s) {
@@ -229,13 +237,14 @@ void test_transaction_for_stream()
 
 void test_transaction_query01()
 {
-  pqxx::connection c;
-  pqxx::work w{c};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
   std::optional<std::tuple<int>> o{
-    w.query01<int>("SELECT * FROM generate_series(1, 1) AS i WHERE i = 5")};
+    tx.query01<int>("SELECT * FROM generate_series(1, 1) AS i WHERE i = 5")};
   PQXX_CHECK(not o.has_value(), "Why did we get a row?");
-  o = w.query01<int>("SELECT * FROM generate_series(8, 8)");
+  o = tx.query01<int>("SELECT * FROM generate_series(8, 8)");
   PQXX_CHECK(o.has_value(), "Why did we not get a row?");
 
   // The "if" is redundant (see the check above).  But gcc 11 complains when
@@ -244,33 +253,34 @@ void test_transaction_query01()
   if (o.has_value())
     PQXX_CHECK_EQUAL(std::get<0>(*o), 8, "Bad value from query01().");
   PQXX_CHECK_THROWS(
-    o = w.query01<int>("SELECT * FROM generate_series(1, 2)"),
+    o = tx.query01<int>("SELECT * FROM generate_series(1, 2)"),
     pqxx::unexpected_rows,
     "Wrong number of rows did not throw unexpected_rows.");
   PQXX_CHECK_THROWS(
-    o = w.query01<int>("SELECT 1, 2"), pqxx::usage_error,
+    o = tx.query01<int>("SELECT 1, 2"), pqxx::usage_error,
     "Wrong number of columns did not throw usage_error.");
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
 void test_transaction_query1()
 {
-  pqxx::connection c;
-  pqxx::work w{c};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
   std::tuple<int> x;
   PQXX_CHECK_THROWS(
-    x = w.query1<int>("SELECT * FROM generate_series(1, 1) AS i WHERE i = 5"),
+    x = tx.query1<int>("SELECT * FROM generate_series(1, 1) AS i WHERE i = 5"),
     pqxx::unexpected_rows, "Zero rows did not throw unexpected_rows.");
   std::optional<std::tuple<int>> const o{
-    w.query1<int>("SELECT * FROM generate_series(8, 8)")};
+    tx.query1<int>("SELECT * FROM generate_series(8, 8)")};
   PQXX_CHECK(o.has_value(), "Why did we not get a row?");
   PQXX_CHECK_EQUAL(std::get<0>(*o), 8, "Bad value from query1().");
   PQXX_CHECK_THROWS(
-    x = w.query1<int>("SELECT * FROM generate_series(1, 2)"),
+    x = tx.query1<int>("SELECT * FROM generate_series(1, 2)"),
     pqxx::unexpected_rows, "Too many rows did not throw unexpected_rows.");
   PQXX_CHECK_THROWS(
-    x = w.query1<int>("SELECT 1, 2"), pqxx::usage_error,
+    x = tx.query1<int>("SELECT 1, 2"), pqxx::usage_error,
     "Wrong number of columns did not throw usage_error.");
   pqxx::ignore_unused(x);
 }
@@ -278,19 +288,21 @@ void test_transaction_query1()
 
 void test_transaction_query_n()
 {
-  pqxx::connection c;
-  pqxx::work w{c};
+  pqxx::connection cx;
+  pqxx::work tx{cx};
 
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
   PQXX_CHECK_THROWS(
-    pqxx::ignore_unused(w.query_n<int>(5, "SELECT generate_series(1, 3)")),
+    pqxx::ignore_unused(tx.query_n<int>(5, "SELECT generate_series(1, 3)")),
     pqxx::unexpected_rows, "No exception when query_n returns too few rows.");
   PQXX_CHECK_THROWS(
-    pqxx::ignore_unused(w.query_n<int>(5, "SELECT generate_series(1, 10)")),
+    pqxx::ignore_unused(tx.query_n<int>(5, "SELECT generate_series(1, 10)")),
     pqxx::unexpected_rows, "No exception when query_n returns too many rows.");
 
   std::vector<int> v;
-  for (auto [n] : w.query_n<int>(3, "SELECT generate_series(7, 9)"))
+  for (auto [n] : tx.query_n<int>(3, "SELECT generate_series(7, 9)"))
     v.push_back(n);
+#include "pqxx/internal/ignore-deprecated-post.hxx"
   PQXX_CHECK_EQUAL(std::size(v), 3u, "Wrong number of rows.");
   PQXX_CHECK_EQUAL(v[0], 7, "Wrong result data.");
   PQXX_CHECK_EQUAL(v[2], 9, "Data started out right but went wrong.");
